%% Statistical Analysis of Motor Noise Data
% This case study analyzes motor noise levels 

%% Load Data for Motors 1-4
% Read data from an Excel worksheet.
rpm = xlsread('MotorData.xls','B4:B24');
motor1 = xlsread('MotorData.xls','C4:F24');
motor2 = xlsread('MotorData.xls','I4:L24');
motor3 = xlsread('MotorData.xls','O4:R24');
motor4 = xlsread('MotorData.xls','U4:X24');

%% Plot Data for Motors 1-4
figure('windowstyle', 'docked'); plot(rpm, motor1); title('Motor 1');
figure('windowstyle', 'docked'); plot(rpm, motor2); title('Motor 2');
figure('windowstyle', 'docked'); plot(rpm, motor3); title('Motor 3');
figure('windowstyle', 'docked'); plot(rpm, motor4); title('Motor 4');

%% Load Data from Benchmark Motor
% Retrieve original motor data from sheet 'Bench'
data1 = xlsread('MotorData.xls', 'Bench');
benchrpm = data1(:,1);
bench = data1(:,2);
clear data1
figure
plot(benchrpm, bench)
xlabel('Motor speed (RPM)'); ylabel('Noise level (dbA)')

%% Model Benchmark Motor Noise  
% Use Curve Fitting Tool to analyze original benchmark motor. Previous
% experience has shown that the noise curve follow the equation
% c-exp(a-b*x)

% Uncomment below if you want to try out cftool
% cftool(benchrpm, bench)
load cf_res


%% Evaluate Fit Quality Using Probability Distributions 
% Use Distribution Fitting Tool to analyze the residuals of our fit.  A
% normal distribution with a mean = 0 and low variance signifies a good
% fit.  
expresiduals = output1.residuals;
dfittool(expresiduals);

%% Compare Motors 1, 2, and 4 to Benchmark
% Plot motor 1 test results with original motor fit
figure('windowstyle', 'docked')
plot(analysisresults1.xi,analysisresults1.upper,':r',...
    'LineWidth',3); hold on
plot(rpm,motor1);title('Motor 1')
xlabel('Motor speed (rpm)');ylabel('Noise');ylim([67 72]);
% Plot motor 2 test results with original motor fit:
figure('windowstyle', 'docked')
plot(analysisresults1.xi,analysisresults1.upper,':r',...
    'LineWidth',3); hold on
plot(rpm,motor2);title('Motor 2')
xlabel('Motor speed (rpm)');ylabel('Noise');ylim([67 72]);
% Plot motor 4 test results with original motor fit:
figure('windowstyle', 'docked')
plot(analysisresults1.xi, analysisresults1.upper,':r',...
    'LineWidth',3); hold on
plot(rpm,motor4);title('Motor 4')
xlabel('Motor speed (rpm)');ylabel('Noise');ylim([67 72]);

%% Evaluate Test Variation Using ANOVA
% Ill use analysis of variance functions from the Statistics Toolbox to
% determine whether test to test differences in motor1 are significant.  
motor1flat = motor1(15:end,:);
[pval,table,stats] = anova1(motor1flat);

%% Normal boxplot
boxplot(motor1flat)

%% 
% Based on the P-value, test-to-test differences are significant.  We have
% to check the reliability of our test setup. 

%% Check Which Tests Differ
% Use multiple comparison plot to see which tests are significantly
% different
multcompare(stats);
